@@ -302,7 +302,8 @@ def get_file_type(f):
             return 'fit' # pragma: no cover
         if extension == '.tcx':
             try:
-                tree = etree.parse(f)
+                p = etree.XMLParser(recover=True)
+                tree = etree.parse(f,parser=p)
                 root = tree.getroot()
                 return 'tcx'
             except: # pragma: no cover
@@ -313,7 +314,8 @@ def get_file_type(f):
                     with open('temp_xml.tcx','w') as fout:
                         fout.write(input)
 
-                    tree = etree.parse('temp_xml.tcx')
+                    p = etree.XMLParser(recover=True)
+                    tree = etree.parse('temp_xml.tcx',parser=p)
                     os.remove('temp_xml.tcx')
                     return 'tcx'
                 except:
@@ -350,7 +352,8 @@ def get_file_type(f):
 
     if extension == '.tcx':
         try:
-            tree = etree.parse(f)
+            p = etree.XMLParser(recover=True)
+            tree = etree.parse(f,parser=p)
             root = tree.getroot()
             return 'tcx'
         except:
@@ -361,7 +364,9 @@ def get_file_type(f):
                 with open('temp_xml.tcx','w') as ftemp:
                     ftemp.write(input)
 
-                tree = etree.parse('temp_xml.tcx')
+                p = etree.XMLParser(recover=True)
+
+                tree = etree.parse('temp_xml.tcx',parser=p)
                 os.remove('temp_xml.tcx')
                 return 'tcx'
             except:
